# scviz
The `scviz` package is a Python library designed for scientific visualization of single cell proteomics data, with plans to support more data types in the future.

## Installation
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install scviz. Currently, scviz is available on testPyPi:
```bash
pip install -i https://test.pypi.org/simple/ scviz
```
A local version of the package can also be installed by:
```bash
$ pip install -e \<insert folder path\>
```

## Usage
Please refer to docs (link) example jupyter notebook: Chapter 1.

## License
`scviz` was created by Marion Pang. It is licensed under the terms of the MIT license.